package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.RmSwitchInterfaceInfo;

/**
 * 交换机接口信息Service接口
 * 
 * @author gyt
 * @date 2025-10-10
 */
public interface IRmSwitchInterfaceInfoService 
{
    /**
     * 查询交换机接口信息
     * 
     * @param id 交换机接口信息主键
     * @return 交换机接口信息
     */
    public RmSwitchInterfaceInfo selectRmSwitchInterfaceInfoById(Long id);

    /**
     * 查询交换机接口信息列表
     * 
     * @param rmSwitchInterfaceInfo 交换机接口信息
     * @return 交换机接口信息集合
     */
    public List<RmSwitchInterfaceInfo> selectRmSwitchInterfaceInfoList(RmSwitchInterfaceInfo rmSwitchInterfaceInfo);

    /**
     * 新增交换机接口信息
     * 
     * @param rmSwitchInterfaceInfo 交换机接口信息
     * @return 结果
     */
    public int insertRmSwitchInterfaceInfo(RmSwitchInterfaceInfo rmSwitchInterfaceInfo);

    /**
     * 修改交换机接口信息
     * 
     * @param rmSwitchInterfaceInfo 交换机接口信息
     * @return 结果
     */
    public int updateRmSwitchInterfaceInfo(RmSwitchInterfaceInfo rmSwitchInterfaceInfo);

    /**
     * 批量删除交换机接口信息
     * 
     * @param ids 需要删除的交换机接口信息主键集合
     * @return 结果
     */
    public int deleteRmSwitchInterfaceInfoByIds(Long[] ids);

    /**
     * 删除交换机接口信息信息
     * 
     * @param id 交换机接口信息主键
     * @return 结果
     */
    public int deleteRmSwitchInterfaceInfoById(Long id);
}
