package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.RmSwitchInterfaceInfo;
import com.ruoyi.system.service.IRmSwitchInterfaceInfoService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 交换机接口信息Controller
 * 
 * @author gyt
 * @date 2025-10-10
 */
@RestController
@RequestMapping("/switchInterfaceInfo")
public class RmSwitchInterfaceInfoController extends BaseController
{
    @Autowired
    private IRmSwitchInterfaceInfoService rmSwitchInterfaceInfoService;

    /**
     * 查询交换机接口信息列表
     */
    @RequiresPermissions("system:switchInterfaceInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(RmSwitchInterfaceInfo rmSwitchInterfaceInfo)
    {
        startPage();
        List<RmSwitchInterfaceInfo> list = rmSwitchInterfaceInfoService.selectRmSwitchInterfaceInfoList(rmSwitchInterfaceInfo);
        return getDataTable(list);
    }

    /**
     * 导出交换机接口信息列表
     */
    @RequiresPermissions("system:switchInterfaceInfo:export")
    @Log(title = "交换机接口信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmSwitchInterfaceInfo rmSwitchInterfaceInfo)
    {
        List<RmSwitchInterfaceInfo> list = rmSwitchInterfaceInfoService.selectRmSwitchInterfaceInfoList(rmSwitchInterfaceInfo);
        ExcelUtil<RmSwitchInterfaceInfo> util = new ExcelUtil<RmSwitchInterfaceInfo>(RmSwitchInterfaceInfo.class);
        util.exportExcel(response, list, "交换机接口信息数据");
    }

    /**
     * 获取交换机接口信息详细信息
     */
    @RequiresPermissions("system:switchInterfaceInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmSwitchInterfaceInfoService.selectRmSwitchInterfaceInfoById(id));
    }

    /**
     * 新增交换机接口信息
     */
    @RequiresPermissions("system:switchInterfaceInfo:add")
    @Log(title = "交换机接口信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmSwitchInterfaceInfo rmSwitchInterfaceInfo)
    {
        return toAjax(rmSwitchInterfaceInfoService.insertRmSwitchInterfaceInfo(rmSwitchInterfaceInfo));
    }

    /**
     * 修改交换机接口信息
     */
    @RequiresPermissions("system:switchInterfaceInfo:edit")
    @Log(title = "交换机接口信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmSwitchInterfaceInfo rmSwitchInterfaceInfo)
    {
        return toAjax(rmSwitchInterfaceInfoService.updateRmSwitchInterfaceInfo(rmSwitchInterfaceInfo));
    }

    /**
     * 删除交换机接口信息
     */
    @RequiresPermissions("system:switchInterfaceInfo:remove")
    @Log(title = "交换机接口信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmSwitchInterfaceInfoService.deleteRmSwitchInterfaceInfoByIds(ids));
    }
}
